# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stream.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import bookkeeper.proto.common_pb2 as common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stream.proto',
  package='bookkeeper.proto.stream',
  syntax='proto3',
  serialized_options=_b('\n\"org.apache.bookkeeper.stream.protoP\001'),
  serialized_pb=_b('\n\x0cstream.proto\x12\x17\x62ookkeeper.proto.stream\x1a\x0c\x63ommon.proto\"=\n\x07RangeId\x12\r\n\x05sc_id\x18\x01 \x01(\x03\x12\x11\n\tstream_id\x18\x02 \x01(\x03\x12\x10\n\x08range_id\x18\x03 \x01(\x03\"8\n\x08KeyRange\x12\x16\n\x0estart_hash_key\x18\x01 \x01(\x03\x12\x14\n\x0c\x65nd_hash_key\x18\x02 \x01(\x03\"o\n\x0fRangeProperties\x12\x16\n\x0estart_hash_key\x18\x01 \x01(\x03\x12\x14\n\x0c\x65nd_hash_key\x18\x02 \x01(\x03\x12\x10\n\x08range_id\x18\x03 \x01(\x03\x12\x1c\n\x14storage_container_id\x18\x04 \x01(\x03\"\xda\x01\n\rRangeMetadata\x12\x37\n\x05props\x18\x01 \x01(\x0b\x32(.bookkeeper.proto.stream.RangeProperties\x12\x10\n\x08revision\x18\x02 \x01(\x03\x12\x32\n\x05state\x18\x03 \x01(\x0e\x32#.bookkeeper.proto.stream.RangeState\x12\x13\n\x0b\x63reate_time\x18\n \x01(\x03\x12\x12\n\nfence_time\x18\x0b \x01(\x03\x12\x10\n\x08\x63hildren\x18\x14 \x03(\x03\x12\x0f\n\x07parents\x18\x15 \x03(\x03\":\n\x0cParentRanges\x12\x10\n\x08range_id\x18\x01 \x01(\x03\x12\x18\n\x10parent_range_ids\x18\x02 \x03(\x03\"O\n\x10ParentRangesList\x12;\n\x0c\x63hild_ranges\x18\x01 \x03(\x0b\x32%.bookkeeper.proto.stream.ParentRanges\"+\n\x15\x46ixedRangeSplitPolicy\x12\x12\n\nnum_ranges\x18\x01 \x01(\x05\"\xa5\x01\n\x19\x42\x61ndwidthBasedSplitPolicy\x12\x19\n\x11max_rate_in_bytes\x18\x01 \x01(\x05\x12\x19\n\x11min_rate_in_bytes\x18\x02 \x01(\x05\x12\x1b\n\x13max_rate_in_records\x18\x03 \x01(\x05\x12\x1b\n\x13min_rate_in_records\x18\x04 \x01(\x05\x12\x18\n\x10max_split_factor\x18\x05 \x01(\x05\"\xed\x01\n\x0bSplitPolicy\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32(.bookkeeper.proto.stream.SplitPolicyType\x12L\n\x12\x66ixed_range_policy\x18\x02 \x01(\x0b\x32..bookkeeper.proto.stream.FixedRangeSplitPolicyH\x00\x12N\n\x10\x62\x61ndwidth_policy\x18\x03 \x01(\x0b\x32\x32.bookkeeper.proto.stream.BandwidthBasedSplitPolicyH\x00\x42\x08\n\x06policy\"9\n\x1dSizeBasedSegmentRollingPolicy\x12\x18\n\x10max_segment_size\x18\x01 \x01(\x03\"9\n\x1dTimeBasedSegmentRollingPolicy\x12\x18\n\x10interval_seconds\x18\x01 \x01(\x03\"\xb0\x01\n\x14SegmentRollingPolicy\x12K\n\x0bsize_policy\x18\x01 \x01(\x0b\x32\x36.bookkeeper.proto.stream.SizeBasedSegmentRollingPolicy\x12K\n\x0btime_policy\x18\x02 \x01(\x0b\x32\x36.bookkeeper.proto.stream.TimeBasedSegmentRollingPolicy\"5\n\x18TimeBasedRetentionPolicy\x12\x19\n\x11retention_minutes\x18\x01 \x01(\x03\"Y\n\x0fRetentionPolicy\x12\x46\n\x0btime_policy\x18\x01 \x01(\x0b\x32\x31.bookkeeper.proto.stream.TimeBasedRetentionPolicy\"\x85\x03\n\x13StreamConfiguration\x12\x37\n\x08key_type\x18\x01 \x01(\x0e\x32%.bookkeeper.proto.stream.RangeKeyType\x12\x16\n\x0emin_num_ranges\x18\x02 \x01(\x05\x12\x1a\n\x12initial_num_ranges\x18\x03 \x01(\x05\x12:\n\x0csplit_policy\x18\x04 \x01(\x0b\x32$.bookkeeper.proto.stream.SplitPolicy\x12\x45\n\x0erolling_policy\x18\x05 \x01(\x0b\x32-.bookkeeper.proto.stream.SegmentRollingPolicy\x12\x42\n\x10retention_policy\x18\x06 \x01(\x0b\x32(.bookkeeper.proto.stream.RetentionPolicy\x12:\n\x0cstorage_type\x18\x07 \x01(\x0e\x32$.bookkeeper.proto.stream.StorageType\"\x9b\x01\n\x10StreamProperties\x12\x11\n\tstream_id\x18\x01 \x01(\x03\x12\x1c\n\x14storage_container_id\x18\x02 \x01(\x03\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12\x41\n\x0bstream_conf\x18\x04 \x01(\x0b\x32,.bookkeeper.proto.stream.StreamConfiguration\"9\n\nStreamName\x12\x16\n\x0enamespace_name\x18\x01 \x01(\t\x12\x13\n\x0bstream_name\x18\x02 \x01(\t\"\xb5\x03\n\x0eStreamMetadata\x12\x38\n\x05props\x18\x01 \x01(\x0b\x32).bookkeeper.proto.stream.StreamProperties\x12O\n\x0flifecycle_state\x18\x02 \x01(\x0e\x32\x36.bookkeeper.proto.stream.StreamMetadata.LifecycleState\x12K\n\rserving_state\x18\x03 \x01(\x0e\x32\x34.bookkeeper.proto.stream.StreamMetadata.ServingState\x12\x0e\n\x06\x63_time\x18\x04 \x01(\x04\x12\x0e\n\x06m_time\x18\x05 \x01(\x04\x12\x15\n\rnext_range_id\x18\x64 \x01(\x04\x12\x16\n\x0e\x63urrent_ranges\x18\x65 \x03(\x04\"P\n\x0eLifecycleState\x12\n\n\x06UNINIT\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07\x43REATED\x10\x02\x12\x0b\n\x07\x46\x45NCING\x10\x03\x12\n\n\x06\x46\x45NCED\x10\x04\"*\n\x0cServingState\x12\x0c\n\x08WRITABLE\x10\x00\x12\x0c\n\x08READONLY\x10\x01\"c\n\x16NamespaceConfiguration\x12I\n\x13\x64\x65\x66\x61ult_stream_conf\x18\x01 \x01(\x0b\x32,.bookkeeper.proto.stream.StreamConfiguration\"\x8e\x01\n\x13NamespaceProperties\x12\x14\n\x0cnamespace_id\x18\x01 \x01(\x03\x12\x16\n\x0enamespace_name\x18\x02 \x01(\t\x12I\n\x13\x64\x65\x66\x61ult_stream_conf\x18\x03 \x01(\x0b\x32,.bookkeeper.proto.stream.StreamConfiguration\"P\n\x11NamespaceMetadata\x12;\n\x05props\x18\x01 \x01(\x0b\x32,.bookkeeper.proto.stream.NamespaceProperties*C\n\nRangeState\x12\x10\n\x0cRANGE_ACTIVE\x10\x00\x12\x11\n\rRANGE_FENCING\x10\x01\x12\x10\n\x0cRANGE_FENCED\x10\x02*+\n\x0cRangeKeyType\x12\x08\n\x04NULL\x10\x00\x12\x08\n\x04HASH\x10\x01\x12\x07\n\x03RAW\x10\x02*$\n\x0bStorageType\x12\n\n\x06STREAM\x10\x00\x12\t\n\x05TABLE\x10\x01*+\n\x0fSplitPolicyType\x12\t\n\x05\x46IXED\x10\x00\x12\r\n\tBANDWIDTH\x10\x01\x42&\n\"org.apache.bookkeeper.stream.protoP\x01\x62\x06proto3')
  ,
  dependencies=[common__pb2.DESCRIPTOR,])

_RANGESTATE = _descriptor.EnumDescriptor(
  name='RangeState',
  full_name='bookkeeper.proto.stream.RangeState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RANGE_ACTIVE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RANGE_FENCING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RANGE_FENCED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2924,
  serialized_end=2991,
)
_sym_db.RegisterEnumDescriptor(_RANGESTATE)

RangeState = enum_type_wrapper.EnumTypeWrapper(_RANGESTATE)
_RANGEKEYTYPE = _descriptor.EnumDescriptor(
  name='RangeKeyType',
  full_name='bookkeeper.proto.stream.RangeKeyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NULL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HASH', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAW', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2993,
  serialized_end=3036,
)
_sym_db.RegisterEnumDescriptor(_RANGEKEYTYPE)

RangeKeyType = enum_type_wrapper.EnumTypeWrapper(_RANGEKEYTYPE)
_STORAGETYPE = _descriptor.EnumDescriptor(
  name='StorageType',
  full_name='bookkeeper.proto.stream.StorageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STREAM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TABLE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3038,
  serialized_end=3074,
)
_sym_db.RegisterEnumDescriptor(_STORAGETYPE)

StorageType = enum_type_wrapper.EnumTypeWrapper(_STORAGETYPE)
_SPLITPOLICYTYPE = _descriptor.EnumDescriptor(
  name='SplitPolicyType',
  full_name='bookkeeper.proto.stream.SplitPolicyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FIXED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BANDWIDTH', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3076,
  serialized_end=3119,
)
_sym_db.RegisterEnumDescriptor(_SPLITPOLICYTYPE)

SplitPolicyType = enum_type_wrapper.EnumTypeWrapper(_SPLITPOLICYTYPE)
RANGE_ACTIVE = 0
RANGE_FENCING = 1
RANGE_FENCED = 2
NULL = 0
HASH = 1
RAW = 2
STREAM = 0
TABLE = 1
FIXED = 0
BANDWIDTH = 1


_STREAMMETADATA_LIFECYCLESTATE = _descriptor.EnumDescriptor(
  name='LifecycleState',
  full_name='bookkeeper.proto.stream.StreamMetadata.LifecycleState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNINIT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FENCING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FENCED', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2470,
  serialized_end=2550,
)
_sym_db.RegisterEnumDescriptor(_STREAMMETADATA_LIFECYCLESTATE)

_STREAMMETADATA_SERVINGSTATE = _descriptor.EnumDescriptor(
  name='ServingState',
  full_name='bookkeeper.proto.stream.StreamMetadata.ServingState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WRITABLE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READONLY', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2552,
  serialized_end=2594,
)
_sym_db.RegisterEnumDescriptor(_STREAMMETADATA_SERVINGSTATE)


_RANGEID = _descriptor.Descriptor(
  name='RangeId',
  full_name='bookkeeper.proto.stream.RangeId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sc_id', full_name='bookkeeper.proto.stream.RangeId.sc_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='bookkeeper.proto.stream.RangeId.stream_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_id', full_name='bookkeeper.proto.stream.RangeId.range_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=116,
)


_KEYRANGE = _descriptor.Descriptor(
  name='KeyRange',
  full_name='bookkeeper.proto.stream.KeyRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_hash_key', full_name='bookkeeper.proto.stream.KeyRange.start_hash_key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_hash_key', full_name='bookkeeper.proto.stream.KeyRange.end_hash_key', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=174,
)


_RANGEPROPERTIES = _descriptor.Descriptor(
  name='RangeProperties',
  full_name='bookkeeper.proto.stream.RangeProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_hash_key', full_name='bookkeeper.proto.stream.RangeProperties.start_hash_key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_hash_key', full_name='bookkeeper.proto.stream.RangeProperties.end_hash_key', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_id', full_name='bookkeeper.proto.stream.RangeProperties.range_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage_container_id', full_name='bookkeeper.proto.stream.RangeProperties.storage_container_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=287,
)


_RANGEMETADATA = _descriptor.Descriptor(
  name='RangeMetadata',
  full_name='bookkeeper.proto.stream.RangeMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='props', full_name='bookkeeper.proto.stream.RangeMetadata.props', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revision', full_name='bookkeeper.proto.stream.RangeMetadata.revision', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='bookkeeper.proto.stream.RangeMetadata.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='bookkeeper.proto.stream.RangeMetadata.create_time', index=3,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fence_time', full_name='bookkeeper.proto.stream.RangeMetadata.fence_time', index=4,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='children', full_name='bookkeeper.proto.stream.RangeMetadata.children', index=5,
      number=20, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parents', full_name='bookkeeper.proto.stream.RangeMetadata.parents', index=6,
      number=21, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=290,
  serialized_end=508,
)


_PARENTRANGES = _descriptor.Descriptor(
  name='ParentRanges',
  full_name='bookkeeper.proto.stream.ParentRanges',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='range_id', full_name='bookkeeper.proto.stream.ParentRanges.range_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_range_ids', full_name='bookkeeper.proto.stream.ParentRanges.parent_range_ids', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=510,
  serialized_end=568,
)


_PARENTRANGESLIST = _descriptor.Descriptor(
  name='ParentRangesList',
  full_name='bookkeeper.proto.stream.ParentRangesList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='child_ranges', full_name='bookkeeper.proto.stream.ParentRangesList.child_ranges', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=649,
)


_FIXEDRANGESPLITPOLICY = _descriptor.Descriptor(
  name='FixedRangeSplitPolicy',
  full_name='bookkeeper.proto.stream.FixedRangeSplitPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_ranges', full_name='bookkeeper.proto.stream.FixedRangeSplitPolicy.num_ranges', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=694,
)


_BANDWIDTHBASEDSPLITPOLICY = _descriptor.Descriptor(
  name='BandwidthBasedSplitPolicy',
  full_name='bookkeeper.proto.stream.BandwidthBasedSplitPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_rate_in_bytes', full_name='bookkeeper.proto.stream.BandwidthBasedSplitPolicy.max_rate_in_bytes', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_rate_in_bytes', full_name='bookkeeper.proto.stream.BandwidthBasedSplitPolicy.min_rate_in_bytes', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_rate_in_records', full_name='bookkeeper.proto.stream.BandwidthBasedSplitPolicy.max_rate_in_records', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_rate_in_records', full_name='bookkeeper.proto.stream.BandwidthBasedSplitPolicy.min_rate_in_records', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_split_factor', full_name='bookkeeper.proto.stream.BandwidthBasedSplitPolicy.max_split_factor', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=862,
)


_SPLITPOLICY = _descriptor.Descriptor(
  name='SplitPolicy',
  full_name='bookkeeper.proto.stream.SplitPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='bookkeeper.proto.stream.SplitPolicy.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fixed_range_policy', full_name='bookkeeper.proto.stream.SplitPolicy.fixed_range_policy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bandwidth_policy', full_name='bookkeeper.proto.stream.SplitPolicy.bandwidth_policy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='policy', full_name='bookkeeper.proto.stream.SplitPolicy.policy',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=865,
  serialized_end=1102,
)


_SIZEBASEDSEGMENTROLLINGPOLICY = _descriptor.Descriptor(
  name='SizeBasedSegmentRollingPolicy',
  full_name='bookkeeper.proto.stream.SizeBasedSegmentRollingPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_segment_size', full_name='bookkeeper.proto.stream.SizeBasedSegmentRollingPolicy.max_segment_size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1104,
  serialized_end=1161,
)


_TIMEBASEDSEGMENTROLLINGPOLICY = _descriptor.Descriptor(
  name='TimeBasedSegmentRollingPolicy',
  full_name='bookkeeper.proto.stream.TimeBasedSegmentRollingPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interval_seconds', full_name='bookkeeper.proto.stream.TimeBasedSegmentRollingPolicy.interval_seconds', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1163,
  serialized_end=1220,
)


_SEGMENTROLLINGPOLICY = _descriptor.Descriptor(
  name='SegmentRollingPolicy',
  full_name='bookkeeper.proto.stream.SegmentRollingPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size_policy', full_name='bookkeeper.proto.stream.SegmentRollingPolicy.size_policy', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_policy', full_name='bookkeeper.proto.stream.SegmentRollingPolicy.time_policy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1223,
  serialized_end=1399,
)


_TIMEBASEDRETENTIONPOLICY = _descriptor.Descriptor(
  name='TimeBasedRetentionPolicy',
  full_name='bookkeeper.proto.stream.TimeBasedRetentionPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='retention_minutes', full_name='bookkeeper.proto.stream.TimeBasedRetentionPolicy.retention_minutes', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1401,
  serialized_end=1454,
)


_RETENTIONPOLICY = _descriptor.Descriptor(
  name='RetentionPolicy',
  full_name='bookkeeper.proto.stream.RetentionPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_policy', full_name='bookkeeper.proto.stream.RetentionPolicy.time_policy', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1456,
  serialized_end=1545,
)


_STREAMCONFIGURATION = _descriptor.Descriptor(
  name='StreamConfiguration',
  full_name='bookkeeper.proto.stream.StreamConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_type', full_name='bookkeeper.proto.stream.StreamConfiguration.key_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_num_ranges', full_name='bookkeeper.proto.stream.StreamConfiguration.min_num_ranges', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial_num_ranges', full_name='bookkeeper.proto.stream.StreamConfiguration.initial_num_ranges', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='split_policy', full_name='bookkeeper.proto.stream.StreamConfiguration.split_policy', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rolling_policy', full_name='bookkeeper.proto.stream.StreamConfiguration.rolling_policy', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='retention_policy', full_name='bookkeeper.proto.stream.StreamConfiguration.retention_policy', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage_type', full_name='bookkeeper.proto.stream.StreamConfiguration.storage_type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1548,
  serialized_end=1937,
)


_STREAMPROPERTIES = _descriptor.Descriptor(
  name='StreamProperties',
  full_name='bookkeeper.proto.stream.StreamProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='bookkeeper.proto.stream.StreamProperties.stream_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage_container_id', full_name='bookkeeper.proto.stream.StreamProperties.storage_container_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_name', full_name='bookkeeper.proto.stream.StreamProperties.stream_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_conf', full_name='bookkeeper.proto.stream.StreamProperties.stream_conf', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1940,
  serialized_end=2095,
)


_STREAMNAME = _descriptor.Descriptor(
  name='StreamName',
  full_name='bookkeeper.proto.stream.StreamName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace_name', full_name='bookkeeper.proto.stream.StreamName.namespace_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_name', full_name='bookkeeper.proto.stream.StreamName.stream_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2097,
  serialized_end=2154,
)


_STREAMMETADATA = _descriptor.Descriptor(
  name='StreamMetadata',
  full_name='bookkeeper.proto.stream.StreamMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='props', full_name='bookkeeper.proto.stream.StreamMetadata.props', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lifecycle_state', full_name='bookkeeper.proto.stream.StreamMetadata.lifecycle_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serving_state', full_name='bookkeeper.proto.stream.StreamMetadata.serving_state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='c_time', full_name='bookkeeper.proto.stream.StreamMetadata.c_time', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='m_time', full_name='bookkeeper.proto.stream.StreamMetadata.m_time', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_range_id', full_name='bookkeeper.proto.stream.StreamMetadata.next_range_id', index=5,
      number=100, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_ranges', full_name='bookkeeper.proto.stream.StreamMetadata.current_ranges', index=6,
      number=101, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STREAMMETADATA_LIFECYCLESTATE,
    _STREAMMETADATA_SERVINGSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2157,
  serialized_end=2594,
)


_NAMESPACECONFIGURATION = _descriptor.Descriptor(
  name='NamespaceConfiguration',
  full_name='bookkeeper.proto.stream.NamespaceConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_stream_conf', full_name='bookkeeper.proto.stream.NamespaceConfiguration.default_stream_conf', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2596,
  serialized_end=2695,
)


_NAMESPACEPROPERTIES = _descriptor.Descriptor(
  name='NamespaceProperties',
  full_name='bookkeeper.proto.stream.NamespaceProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace_id', full_name='bookkeeper.proto.stream.NamespaceProperties.namespace_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace_name', full_name='bookkeeper.proto.stream.NamespaceProperties.namespace_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_stream_conf', full_name='bookkeeper.proto.stream.NamespaceProperties.default_stream_conf', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2698,
  serialized_end=2840,
)


_NAMESPACEMETADATA = _descriptor.Descriptor(
  name='NamespaceMetadata',
  full_name='bookkeeper.proto.stream.NamespaceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='props', full_name='bookkeeper.proto.stream.NamespaceMetadata.props', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2842,
  serialized_end=2922,
)

_RANGEMETADATA.fields_by_name['props'].message_type = _RANGEPROPERTIES
_RANGEMETADATA.fields_by_name['state'].enum_type = _RANGESTATE
_PARENTRANGESLIST.fields_by_name['child_ranges'].message_type = _PARENTRANGES
_SPLITPOLICY.fields_by_name['type'].enum_type = _SPLITPOLICYTYPE
_SPLITPOLICY.fields_by_name['fixed_range_policy'].message_type = _FIXEDRANGESPLITPOLICY
_SPLITPOLICY.fields_by_name['bandwidth_policy'].message_type = _BANDWIDTHBASEDSPLITPOLICY
_SPLITPOLICY.oneofs_by_name['policy'].fields.append(
  _SPLITPOLICY.fields_by_name['fixed_range_policy'])
_SPLITPOLICY.fields_by_name['fixed_range_policy'].containing_oneof = _SPLITPOLICY.oneofs_by_name['policy']
_SPLITPOLICY.oneofs_by_name['policy'].fields.append(
  _SPLITPOLICY.fields_by_name['bandwidth_policy'])
_SPLITPOLICY.fields_by_name['bandwidth_policy'].containing_oneof = _SPLITPOLICY.oneofs_by_name['policy']
_SEGMENTROLLINGPOLICY.fields_by_name['size_policy'].message_type = _SIZEBASEDSEGMENTROLLINGPOLICY
_SEGMENTROLLINGPOLICY.fields_by_name['time_policy'].message_type = _TIMEBASEDSEGMENTROLLINGPOLICY
_RETENTIONPOLICY.fields_by_name['time_policy'].message_type = _TIMEBASEDRETENTIONPOLICY
_STREAMCONFIGURATION.fields_by_name['key_type'].enum_type = _RANGEKEYTYPE
_STREAMCONFIGURATION.fields_by_name['split_policy'].message_type = _SPLITPOLICY
_STREAMCONFIGURATION.fields_by_name['rolling_policy'].message_type = _SEGMENTROLLINGPOLICY
_STREAMCONFIGURATION.fields_by_name['retention_policy'].message_type = _RETENTIONPOLICY
_STREAMCONFIGURATION.fields_by_name['storage_type'].enum_type = _STORAGETYPE
_STREAMPROPERTIES.fields_by_name['stream_conf'].message_type = _STREAMCONFIGURATION
_STREAMMETADATA.fields_by_name['props'].message_type = _STREAMPROPERTIES
_STREAMMETADATA.fields_by_name['lifecycle_state'].enum_type = _STREAMMETADATA_LIFECYCLESTATE
_STREAMMETADATA.fields_by_name['serving_state'].enum_type = _STREAMMETADATA_SERVINGSTATE
_STREAMMETADATA_LIFECYCLESTATE.containing_type = _STREAMMETADATA
_STREAMMETADATA_SERVINGSTATE.containing_type = _STREAMMETADATA
_NAMESPACECONFIGURATION.fields_by_name['default_stream_conf'].message_type = _STREAMCONFIGURATION
_NAMESPACEPROPERTIES.fields_by_name['default_stream_conf'].message_type = _STREAMCONFIGURATION
_NAMESPACEMETADATA.fields_by_name['props'].message_type = _NAMESPACEPROPERTIES
DESCRIPTOR.message_types_by_name['RangeId'] = _RANGEID
DESCRIPTOR.message_types_by_name['KeyRange'] = _KEYRANGE
DESCRIPTOR.message_types_by_name['RangeProperties'] = _RANGEPROPERTIES
DESCRIPTOR.message_types_by_name['RangeMetadata'] = _RANGEMETADATA
DESCRIPTOR.message_types_by_name['ParentRanges'] = _PARENTRANGES
DESCRIPTOR.message_types_by_name['ParentRangesList'] = _PARENTRANGESLIST
DESCRIPTOR.message_types_by_name['FixedRangeSplitPolicy'] = _FIXEDRANGESPLITPOLICY
DESCRIPTOR.message_types_by_name['BandwidthBasedSplitPolicy'] = _BANDWIDTHBASEDSPLITPOLICY
DESCRIPTOR.message_types_by_name['SplitPolicy'] = _SPLITPOLICY
DESCRIPTOR.message_types_by_name['SizeBasedSegmentRollingPolicy'] = _SIZEBASEDSEGMENTROLLINGPOLICY
DESCRIPTOR.message_types_by_name['TimeBasedSegmentRollingPolicy'] = _TIMEBASEDSEGMENTROLLINGPOLICY
DESCRIPTOR.message_types_by_name['SegmentRollingPolicy'] = _SEGMENTROLLINGPOLICY
DESCRIPTOR.message_types_by_name['TimeBasedRetentionPolicy'] = _TIMEBASEDRETENTIONPOLICY
DESCRIPTOR.message_types_by_name['RetentionPolicy'] = _RETENTIONPOLICY
DESCRIPTOR.message_types_by_name['StreamConfiguration'] = _STREAMCONFIGURATION
DESCRIPTOR.message_types_by_name['StreamProperties'] = _STREAMPROPERTIES
DESCRIPTOR.message_types_by_name['StreamName'] = _STREAMNAME
DESCRIPTOR.message_types_by_name['StreamMetadata'] = _STREAMMETADATA
DESCRIPTOR.message_types_by_name['NamespaceConfiguration'] = _NAMESPACECONFIGURATION
DESCRIPTOR.message_types_by_name['NamespaceProperties'] = _NAMESPACEPROPERTIES
DESCRIPTOR.message_types_by_name['NamespaceMetadata'] = _NAMESPACEMETADATA
DESCRIPTOR.enum_types_by_name['RangeState'] = _RANGESTATE
DESCRIPTOR.enum_types_by_name['RangeKeyType'] = _RANGEKEYTYPE
DESCRIPTOR.enum_types_by_name['StorageType'] = _STORAGETYPE
DESCRIPTOR.enum_types_by_name['SplitPolicyType'] = _SPLITPOLICYTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RangeId = _reflection.GeneratedProtocolMessageType('RangeId', (_message.Message,), dict(
  DESCRIPTOR = _RANGEID,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.RangeId)
  ))
_sym_db.RegisterMessage(RangeId)

KeyRange = _reflection.GeneratedProtocolMessageType('KeyRange', (_message.Message,), dict(
  DESCRIPTOR = _KEYRANGE,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.KeyRange)
  ))
_sym_db.RegisterMessage(KeyRange)

RangeProperties = _reflection.GeneratedProtocolMessageType('RangeProperties', (_message.Message,), dict(
  DESCRIPTOR = _RANGEPROPERTIES,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.RangeProperties)
  ))
_sym_db.RegisterMessage(RangeProperties)

RangeMetadata = _reflection.GeneratedProtocolMessageType('RangeMetadata', (_message.Message,), dict(
  DESCRIPTOR = _RANGEMETADATA,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.RangeMetadata)
  ))
_sym_db.RegisterMessage(RangeMetadata)

ParentRanges = _reflection.GeneratedProtocolMessageType('ParentRanges', (_message.Message,), dict(
  DESCRIPTOR = _PARENTRANGES,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.ParentRanges)
  ))
_sym_db.RegisterMessage(ParentRanges)

ParentRangesList = _reflection.GeneratedProtocolMessageType('ParentRangesList', (_message.Message,), dict(
  DESCRIPTOR = _PARENTRANGESLIST,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.ParentRangesList)
  ))
_sym_db.RegisterMessage(ParentRangesList)

FixedRangeSplitPolicy = _reflection.GeneratedProtocolMessageType('FixedRangeSplitPolicy', (_message.Message,), dict(
  DESCRIPTOR = _FIXEDRANGESPLITPOLICY,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.FixedRangeSplitPolicy)
  ))
_sym_db.RegisterMessage(FixedRangeSplitPolicy)

BandwidthBasedSplitPolicy = _reflection.GeneratedProtocolMessageType('BandwidthBasedSplitPolicy', (_message.Message,), dict(
  DESCRIPTOR = _BANDWIDTHBASEDSPLITPOLICY,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.BandwidthBasedSplitPolicy)
  ))
_sym_db.RegisterMessage(BandwidthBasedSplitPolicy)

SplitPolicy = _reflection.GeneratedProtocolMessageType('SplitPolicy', (_message.Message,), dict(
  DESCRIPTOR = _SPLITPOLICY,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.SplitPolicy)
  ))
_sym_db.RegisterMessage(SplitPolicy)

SizeBasedSegmentRollingPolicy = _reflection.GeneratedProtocolMessageType('SizeBasedSegmentRollingPolicy', (_message.Message,), dict(
  DESCRIPTOR = _SIZEBASEDSEGMENTROLLINGPOLICY,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.SizeBasedSegmentRollingPolicy)
  ))
_sym_db.RegisterMessage(SizeBasedSegmentRollingPolicy)

TimeBasedSegmentRollingPolicy = _reflection.GeneratedProtocolMessageType('TimeBasedSegmentRollingPolicy', (_message.Message,), dict(
  DESCRIPTOR = _TIMEBASEDSEGMENTROLLINGPOLICY,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.TimeBasedSegmentRollingPolicy)
  ))
_sym_db.RegisterMessage(TimeBasedSegmentRollingPolicy)

SegmentRollingPolicy = _reflection.GeneratedProtocolMessageType('SegmentRollingPolicy', (_message.Message,), dict(
  DESCRIPTOR = _SEGMENTROLLINGPOLICY,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.SegmentRollingPolicy)
  ))
_sym_db.RegisterMessage(SegmentRollingPolicy)

TimeBasedRetentionPolicy = _reflection.GeneratedProtocolMessageType('TimeBasedRetentionPolicy', (_message.Message,), dict(
  DESCRIPTOR = _TIMEBASEDRETENTIONPOLICY,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.TimeBasedRetentionPolicy)
  ))
_sym_db.RegisterMessage(TimeBasedRetentionPolicy)

RetentionPolicy = _reflection.GeneratedProtocolMessageType('RetentionPolicy', (_message.Message,), dict(
  DESCRIPTOR = _RETENTIONPOLICY,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.RetentionPolicy)
  ))
_sym_db.RegisterMessage(RetentionPolicy)

StreamConfiguration = _reflection.GeneratedProtocolMessageType('StreamConfiguration', (_message.Message,), dict(
  DESCRIPTOR = _STREAMCONFIGURATION,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.StreamConfiguration)
  ))
_sym_db.RegisterMessage(StreamConfiguration)

StreamProperties = _reflection.GeneratedProtocolMessageType('StreamProperties', (_message.Message,), dict(
  DESCRIPTOR = _STREAMPROPERTIES,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.StreamProperties)
  ))
_sym_db.RegisterMessage(StreamProperties)

StreamName = _reflection.GeneratedProtocolMessageType('StreamName', (_message.Message,), dict(
  DESCRIPTOR = _STREAMNAME,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.StreamName)
  ))
_sym_db.RegisterMessage(StreamName)

StreamMetadata = _reflection.GeneratedProtocolMessageType('StreamMetadata', (_message.Message,), dict(
  DESCRIPTOR = _STREAMMETADATA,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.StreamMetadata)
  ))
_sym_db.RegisterMessage(StreamMetadata)

NamespaceConfiguration = _reflection.GeneratedProtocolMessageType('NamespaceConfiguration', (_message.Message,), dict(
  DESCRIPTOR = _NAMESPACECONFIGURATION,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.NamespaceConfiguration)
  ))
_sym_db.RegisterMessage(NamespaceConfiguration)

NamespaceProperties = _reflection.GeneratedProtocolMessageType('NamespaceProperties', (_message.Message,), dict(
  DESCRIPTOR = _NAMESPACEPROPERTIES,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.NamespaceProperties)
  ))
_sym_db.RegisterMessage(NamespaceProperties)

NamespaceMetadata = _reflection.GeneratedProtocolMessageType('NamespaceMetadata', (_message.Message,), dict(
  DESCRIPTOR = _NAMESPACEMETADATA,
  __module__ = 'stream_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.stream.NamespaceMetadata)
  ))
_sym_db.RegisterMessage(NamespaceMetadata)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
